/*
Copyright 2020 Peter Howkins

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#include <string.h>
#include <stdio.h>
#include "stdint.h"
#include "os.h"
#include "support.h"

void
MODE(uint8_t mode)
{
	oswrch(22);
	oswrch(mode);
}

void
COLOUR(uint8_t colour)
{
	oswrch(17);
	oswrch(colour);
}

void
GCOL(uint8_t action, uint8_t colour)
{
	oswrch(18);
	oswrch(action);
	oswrch(colour);
}

void
PLOT(uint8_t plotcode, uint16_t x, uint16_t y)
{
	oswrch(25);
	oswrch(plotcode);
	oswrch(x); oswrch(x >> 8);
	oswrch(y); oswrch(y >> 8);
}

void
SOUND(int16_t channel, int16_t amplitude, int16_t pitch, int16_t duration)
{
	uint8_t block[8];

	block[0] = (uint8_t)    channel;
	block[1] = (uint8_t)   (channel >> 8);
	block[2] = (uint8_t)  amplitude;
	block[3] = (uint8_t) (amplitude >> 8);
	block[4] = (uint8_t)      pitch;
	block[5] = (uint8_t)     (pitch >> 8);
	block[6] = (uint8_t)   duration;
	block[7] = (uint8_t)  (duration >> 8);

	osword(7, block);
}

void
PRINTTAB(uint8_t x, uint8_t y, const char *string)
{
	oswrch(31);
	oswrch(x);
	oswrch(y);

	putstring(string);
}

uint8_t
INKEYNEG(int8_t key)
{
	uint8_t x = (uint8_t) key;
	uint8_t y = 255;

	osbyte(0x81, &x, &y);

	if(x == 255) {
		/* Is pressed */
		return 1;
	}
	/* not pressed */
	return 0;
}

