/*
Copyright 2020 Peter Howkins

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#include <stdio.h>
#include "stdint.h"

#include "support.h"
#include "os.h"

void
putstring(const char *s)
{
	while(*s) {
		putchar(*s);
		s++;
	}
}

/**
 * Output an 8bit unsigned int to the screen in hex
 */
void
puth(uint8_t n)
{
	uint8_t topfour = (n & 0xf0) >> 4;
	uint8_t botfour = n & 0xf;

	if(topfour < 10) {
		putchar(topfour + 48);
	} else {
		putchar(topfour + 97 - 10);
	}
	if(botfour < 10) {
		putchar(botfour + 48);
	} else {
		putchar(botfour + 97 - 10);
	}
}

void
puthtab(uint8_t x, uint8_t y, uint8_t n)
{
	oswrch(31);
	oswrch(x);
	oswrch(y);

	puth(n);
}

/**
 * src: https://en.wikibooks.org/wiki/C_Programming/stdlib.h/itoa
 *
 * One bug in src implementation, cannot output largest negative number
 * (-2147483648)
 *
 * Function returns pointer to static data and is not reentrant
 */
char *
dtos(int32_t n)
{
	static char ret[11];
	char s[11]; /* max is -2147483648 */

	int16_t i, j, k;
	int32_t sign;
 
	if ((sign = n) < 0) { /* record sign */
		n = -n;          /* make n positive */
	}
	i = 0;
	do {       /* generate digits in reverse order */
		s[i++] = n % 10 + '0';   /* get next digit */
	} while ((n /= 10) > 0);     /* delete it */
	if(sign < 0) {
		s[i++] = '-';
	}

	k = 0;
	/* String is generated in reverse */
	for(j = i - 1; j >= 0; j--) {
		ret[k] = s[j];
		k++;
	}
	ret[k] = '\0';
	return ret;
}

void
putd(int32_t n)
{
	putstring(dtos(n));
}

void
putdtab(uint8_t x, uint8_t y, int32_t n)
{
	oswrch(31);
	oswrch(x);
	oswrch(y);

	putstring(dtos(n));
}
