/*
Copyright 2020 Peter Howkins

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the
"Software"), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
#ifndef SUPPORT_H
#define SUPPORT_H

/**
 * @file
 * @brief Misc support functions
 * 
 * Misc support functions including number output
 */


/**
 * Output a zero terminated string without a newline char
 *
 * @param s string
 */
extern void
putstring(const char *s);

/**
 * output an 8bit hex number
 * 
 * @param n number
 */ 
extern void
puth(uint8_t n);

/**
 * output an 8bit hex number at a particular text coordinate
 * 
 * @param x text coordinate
 * @param y text coordinate
 * @param n number
 */
extern void
puthtab(uint8_t x, uint8_t y, uint8_t n);

/**
 * output a 32bit signed decimal number
 * 
 * @param d number
 */ 
extern void
putd(int32_t d);

/**
 * output a 32bit signed decimal number
 * 
 * @param x text coordinate
 * @param y text coordinate
 * @param d number
 */ 
extern void
putdtab(uint8_t x, uint8_t y, int32_t d);

/**
 * Convert a number to a string
 *
 * @oaram d number
 * @returns pointer to output string, static data, function is not reentrant
 */
extern char *
dtos(int32_t d);


#endif /* SUPPORT_H */
